# leftpad
`leftpad` is a Python library for padding the left of strings.

# Installation
`pip install leftpadx`

# Usage
```
from leftpad import leftpad

print(leftpad("epic", 100, "@"))
```
Expected output:
```
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@epic
```